import { Storage } from '@ionic/storage';
/**
 * Classe responsável pelo gerenciamento de variável em memória/storage do dispositivo
 * Ao utilizar os métodos da classe para atualizar o valor em memória, por padrão,
 * o valor é refletido no storage
 */
export declare class StorageUtil<T> {
    private storage;
    /** Sufixo padrão */
    private static SUFFIX_DEFAULT;
    /**
     * Campo id para facilitar buscas
     */
    private _id;
    readonly id: string;
    /**
     * Indica que o storage é exclusivo
     */
    private _exclusive;
    readonly exclusive: boolean;
    /**
     * Indica a função de sufixo quando o storage é exclusivoIndica a função de sufixo quando o storage é exclusivo
     */
    private _suffixFn;
    readonly suffixFn: Function;
    /**
     * Indica a função de inicialização de dados quando o storage está vazio
     */
    private _initFn;
    readonly initFn: Function;
    /**
     * Nome da chave no storage para get/set
     */
    private _name;
    readonly name: string;
    /**
     * Conteúdo a ser refletido
     */
    private _data;
    data: T;
    /**
     * Sufixo corrente quando storage exclusivo
     */
    readonly currentSuffix: string;
    /**
     * Indica que a classe já foi inicializada corretamente
     */
    private _init;
    readonly isInit: boolean;
    /**
     * Se uma operação que trava o registro está em andamento
     */
    private _lock;
    readonly isLock: boolean;
    /**
     * Construtor da classe
     * @param storage Recebe o Storage via Angular Dependency Injection
     */
    constructor(storage: Storage);
    /**
     * Configura e realiza a leitura de dados do storage
     * @param { name:string, id? :string, exclusive?: boolean, suffixFn?: Function, lazy?: boolean, initFn?: Function}
     */
    config({name, id, exclusive, suffixFn, lazy, initFn}?: {
        name: string;
        id?: string;
        exclusive?: boolean;
        suffixFn?: Function;
        lazy?: boolean;
        initFn?: Function;
    }): Promise<void | T>;
    /**
     * Atualiza o storage para refletir o valor contido em memória
     */
    updateStorage(): Promise<T>;
    /**
     * Ferramenta utilizada para encontrar algum valor em um subnível
     * @param search
     * @param fields
     * @example
     * storage.data = [{ nome: 'joao', endereco: {rua: 'qualquer', numero: 123}}]
     * storage.find(123,'endereco','numero').then(endereco =>{
     * endereco.numero = 234
     * storage.updateStorage()})
     */
    find(search: any, ...fields: string[]): Promise<any>;
    /**
     * Atualiza a variavel em memória e reflete no storage.
     * Pode-se acessar um subnível passando no fields o nível que deseja acessar,
     * @example
     * // exemplo 1:
     * storage.data == {campoa:'valor', campob:{ campox: 'valor2'}}
     * storage.set('novovalor',true,'campob','campox')
     * // Resultado objeto: {campoa:'valor', campob:{ campox: 'novovalor'}}
     * // exemplo 2:
     * storage.data == [ {campoa:'valor', campob:{ campox: 'valor2'}}, {campoa:'valor', campob:{ campox: 'valork'}} ]
     * storage.set('novovalorx',true,1,'campob','campox')
     * // Caso atualizar o storage.data diretamente, chamar updateStorage para refletir os dados no storage
     * @param newData
     * @param save
     * @param fields
     */
    set(newData: any, save?: boolean, ...fields: string[]): Promise<T>;
    /**
     * Faz a leitura do storage se ainda não foi feita ou da variável de memória
     * @param search Busca em campo que representa uma chave primária do objeto
     */
    get(search: any): Promise<any>;
    /**
     * Faz a leitura dos dados que estão no storage
     */
    read(): Promise<void | T>;
    /**
     * Reinicializa o storage, persistindo os dados de inicialização
     */
    reset(): Promise<void | T>;
    /**
     * Remove um item de um array, atualiza no storage e retorna uma promessa de item atualizado.
     * @param search
     */
    delete(search: any): Promise<T>;
    /**
     * Atualiza o valor em memória lida do storage
     * @param value
     */
    private updateData(value);
    /**
     * Inicializa o armazenamento com base na função que o usuário informou
     */
    private init(data);
    /**
     * Função recursíva para encontrar subníveis automáticamente
     * @param x array de campos recursivos
     * @param data a informação
     * @param level nível de iteração
     */
    private recursiveField(fields, data, level?);
    /**
     * Recupera os dados do sufíxo atual
     */
    private getCurrentSuffixData();
}
